#
# spec file for package perl-XML-XPath
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name XML-XPath
Name:           perl-XML-XPath
Version:        1.48
Release:        1.7
License:        Artistic-2.0
Summary:        Parse and evaluate XPath statements
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MANWAR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Path::Tiny) >= 0.076
BuildRequires:  perl(Scalar::Util) >= 1.45
BuildRequires:  perl(XML::Parser) >= 2.23
Requires:       perl(Scalar::Util) >= 1.45
Requires:       perl(XML::Parser) >= 2.23
%{perl_requires}

%description
This module aims to comply exactly to the XPath specification at
http://www.w3.org/TR/xpath and yet allow extensions to be added in the form
of functions.Modules such as XSLT and XPointer may need to do this as they
support functionality beyond XPath.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README TODO
%license LICENSE

%changelog
* Wed Aug 10 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.48
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.48  2022-08-09 MANWAR
  - More contributions by @shawnm.
    a) pull request #11
    Support use XML::XPath some_version; and modernize inheritance.
    b) pull request #12
    Add documentation about supported XPath functions.
* Sat May 14 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.47
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.47  2022-05-13 MANWAR
  - Another bunch of patches, thanks @shawnm.
    a) Get the encoding used for command line arguments from
    the environment.
    b) Don't assume standard input and output are UTF-8; also
    get their encoding from the environment.
  1.46  2022-05-12 MANWAR
  - Added missing unit test (t/52matches.t)
  - Added missing unit test (t/cleanup.t)
  - Added unit test for MANIFEST (t/manifest.t)
  1.45  2022-05-12 MANWAR
  - Added XPath function matches(), thanks @shawnw.
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.44
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.44  2018-10-11 MANWAR
  - Added new test for axis descendant.
  1.43  2018-10-10 MANWAR
  - Fix memory leak in XML::XPath::Parser (PR #6), Thanks @niner.
* Thu Aug  3 2017 coolo@suse.com
- updated to 1.42
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.42  2017-07-30 MANWAR
  - Fixed GitHub issue #5 (abstract is undef in meta files). Thanks @y.
* Sat Jul 29 2017 coolo@suse.com
- updated to 1.41
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.41  2017-07-28 MANWAR
  - Fixed GitHub issue #4 (can't use non-ascii first character as element name). Thanks @nanis, @ikegami.
* Mon Nov 14 2016 coolo@suse.com
- updated to 1.40
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.40  2016-11-13 MANWAR
  - Proposed fix for RT #118726.
* Fri Nov 11 2016 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.39  2016-11-08 MANWAR
  - Proposed fix for RT #118643.
* Tue Nov  1 2016 coolo@suse.com
- updated to 1.38
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.38  2016-10-31 MANWAR
  - Fixed parser caching as reported by Jeremy (mysticprune).
* Sun Jun 12 2016 coolo@suse.com
- updated to 1.37
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.37  2016-06-02 MANWAR
  - Fixed annoying warnings.
* Thu May  5 2016 coolo@suse.com
- updated to 1.36
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.36  2016-04-14 MANWAR
  - Fixed issue RT #68932 (/usr/bin/xpath outputs unwanted text when quiet mode ist set).
* Thu Apr  7 2016 coolo@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.35  2016-04-06 MANWAR
  - Fixed issue RT #113576 (XML::XPath::Node::Element::getAttributeNode() uses unspecified behaviour).
* Fri Mar 11 2016 coolo@suse.com
- updated to 1.34
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.34  2016-03-08 MANWAR
  - Applied the patch to script examples/xpath (kindly provided by GREGOA).
* Mon Mar  7 2016 coolo@suse.com
- updated to 1.33
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.33  2016-03-02 MANWAR
  - Fixed issue RT #112584 (use of /d modifier in transliteration operator).
  1.32  2016-02-23 MANWAR
  - Applied the following patches kindly provided by GREGOA:
    https://anonscm.debian.org/cgit/pkg-perl/packages/libxml-xpath-perl.git/tree/debian/patches/fix-stringification-overload.patch
    https://anonscm.debian.org/cgit/pkg-perl/packages/libxml-xpath-perl.git/tree/debian/patches/test.patch
    https://anonscm.debian.org/cgit/pkg-perl/packages/libxml-xpath-perl.git/tree/debian/patches/xpath-option-to-work-without-internet-connection.patch
* Tue Feb 23 2016 coolo@suse.com
- updated to 1.31
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.31  2016-02-22 MANWAR
  - Proposed fix for RT #112017.
* Sun Feb  7 2016 coolo@suse.com
- updated to 1.30
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.30  2016-02-04 MANWAR
  - Fixed issue RT #15902 (Quoting warnings with translate).
  - Fixed issue RT #21154 (translate() function does not remove characters or support -)
  1.29  2016-02-03 MANWAR
  - Fixed issue RT# 26144 (createNode doesn't honor position() predicate).
  1.28  2016-01-31 MANWAR
  - Changed the LICENSE information about the package XML::XPath::PerlSAX as per
    Matt Sergeant email response (dated 2016-01-30).
  1.27  2016-01-30 MANWAR
  - Fixed issue RT# 32012 (Debian bug #187583, http://bugs.debian.org/187583).
* Wed Jan 27 2016 coolo@suse.com
- updated to 1.26
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.26  2016-01-25 MANWAR
  - Fixed inconsistent version issue (CPANTS).
  - Added key 'provides' to the Makefile.PL script.
  - Added unit test scripts t/meta-json.t and t/meta-yml.t
  1.25  2016-01-20 MANWAR
  - Merged in GitHub PR #2, thanks to sdeseille.
  - Merged t/45overloading_number_operator.t and t/99rt_11724.t into t/45cmp_nodeset.t
* Wed Jan 20 2016 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.24  2016-01-19 MANWAR
  - Fixed issue RT# 111278 (XML::XPath::PerlSAX doesn't compile).
* Tue Jan 19 2016 coolo@suse.com
- updated to 1.23
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.23  2016-01-18 MANWAR
  - Fixed issues RT# 6363 (using < in a query returns results as if <= had been used).
  1.22  2016-01-13 MANWAR
  - Fixed issues RT# 30818 and RT# 80277.
* Wed Jan 13 2016 coolo@suse.com
- updated to 1.21
  see /usr/share/doc/packages/perl-XML-XPath/Changes
  1.21  2016-01-12 MANWAR
  - Fixed issues RT# 14957 and RT# 30819.
  1.20  2016-01-10 MANWAR
  - Fixed issues RT# 26143 and RT# 68703.
* Wed Jan  6 2016 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-XML-XPath/Changes
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Jul 30 2007 mvidner@suse.cz
- package created, needed for yast2-metapackage-handler
- v 1.13
